@@ -99,7 +99,7 @@ private:
 	void read_uuid( Partition & partition ) ;
 	void set_mountpoints( Partition & partition );
 	bool set_mountpoints_helper( Partition & partition, const Glib::ustring & path );
-	bool is_busy( FSType fstype, const Glib::ustring & path );
+	bool is_busy(const Glib::ustring& device_path, FSType fstype, const Glib::ustring& partition_path);
 	void set_used_sectors( Partition & partition, PedDisk* lp_disk );
 	void mounted_fs_set_used_sectors(Partition& partition);
 #ifdef HAVE_LIBPARTED_FS_RESIZE
