@@ -96,18 +96,20 @@ enum FSType
 	// Other recognised file system types
 	FS_APFS            = 28,
 	FS_ATARAID         = 29,
-	FS_BITLOCKER       = 30,
-	FS_GRUB2_CORE_IMG  = 31,
-	FS_ISO9660         = 32,
-	FS_LINUX_SWRAID    = 33,
-	FS_LINUX_SWSUSPEND = 34,
-	FS_REFS            = 35,
-	FS_UFS             = 36,
-	FS_ZFS             = 37,
+	FS_BCACHE          = 30,
+	FS_BITLOCKER       = 31,
+	FS_GRUB2_CORE_IMG  = 32,
+	FS_ISO9660         = 33,
+	FS_JBD             = 34,
+	FS_LINUX_SWRAID    = 35,
+	FS_LINUX_SWSUSPEND = 36,
+	FS_REFS            = 37,
+	FS_UFS             = 38,
+	FS_ZFS             = 39,
 
 	// Partition space usage colours
-	FS_USED            = 38,
-	FS_UNUSED          = 39
+	FS_USED            = 40,
+	FS_UNUSED          = 41
 } ;
 
 enum SIZE_UNIT
@@ -181,6 +183,7 @@ public:
 	static int get_mounted_filesystem_usage( const Glib::ustring & mountpoint,
 	                                         Byte_Value & fs_size, Byte_Value & fs_free,
 	                                         Glib::ustring & error_message ) ;
+	static bool is_dev_busy(const Glib::ustring& path);
 	static Byte_Value floor_size( Byte_Value value, Byte_Value rounding_size ) ;
 	static Byte_Value ceil_size( Byte_Value value, Byte_Value rounding_size ) ;
 
