@@ -66,6 +66,7 @@ FS btrfs::get_filesystem_support()
 		fs .read_uuid = FS::EXTERNAL ;
 		fs.check = FS::EXTERNAL;
 		fs.write_label = FS::EXTERNAL;
+		fs.online_write_label = FS::EXTERNAL;
 
 		//Resizing of btrfs requires mount, umount and kernel
 		//  support as well as btrfs filesystem resize
@@ -261,19 +262,31 @@ void btrfs::set_used_sectors( Partition & partition )
 	}
 }
 
+
 bool btrfs::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "btrfs filesystem label " + Glib::shell_quote( partition.get_path() ) +
-	                          " " + Glib::shell_quote( partition.get_filesystem_label() ),
-	                          operationdetail, EXEC_CHECK_STATUS );
+	// Use the mount point when labelling a mounted btrfs, or block device containing
+	// the unmounted btrfs.
+	//     btrfs filesystem label '/dev/PTN' 'NEWLABEL'
+	//     btrfs filesystem label '/MNTPNT' 'NEWLABEL'
+	Glib::ustring path;
+	if (partition.busy)
+		path = partition.get_mountpoint();
+	else
+		path = partition.get_path();
+
+	return ! execute_command("btrfs filesystem label " + Glib::shell_quote(path) +
+	                         " " + Glib::shell_quote(partition.get_filesystem_label()),
+	                         operationdetail, EXEC_CHECK_STATUS);
 }
 
+
 bool btrfs::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	bool success = true ;
-	Glib::ustring path = partition_new .get_path() ;
+	const Glib::ustring& path = partition_new.get_path();
+	const BTRFS_Device& btrfs_dev = get_cache_entry(path);
 
-	BTRFS_Device btrfs_dev = get_cache_entry( path ) ;
 	if ( btrfs_dev .devid == -1 )
 	{
 		operationdetail .add_child( OperationDetail(
@@ -387,7 +400,8 @@ void btrfs::clear_cache()
 //  Return empty string if not found (not mounted).
 Glib::ustring btrfs::get_mount_device( const Glib::ustring & path )
 {
-	BTRFS_Device btrfs_dev = get_cache_entry( path ) ;
+	const BTRFS_Device& btrfs_dev = get_cache_entry(path);
+
 	if ( btrfs_dev .devid == -1 || btrfs_dev .members .empty() )
 	{
 		//WARNING:
@@ -408,7 +422,7 @@ Glib::ustring btrfs::get_mount_device( const Glib::ustring & path )
 
 std::vector<Glib::ustring> btrfs::get_members( const Glib::ustring & path )
 {
-	BTRFS_Device btrfs_dev = get_cache_entry( path ) ;
+	const BTRFS_Device& btrfs_dev = get_cache_entry(path);
 	std::vector<Glib::ustring> membs;
 	for ( unsigned int i = 0 ; i < btrfs_dev.members.size() ; i ++ )
 		membs.push_back( btrfs_dev.members[i].m_name );
